execute_permute_blocked

Function execute_permute_blocked 

pub unsafe fn execute_permute_blocked<T: Copy>(
    src: *const T,
    dst: *mut T,
    plan: &PermutePlan,
)
Execute the permutation plan (single-threaded).

Safety

  • src must be valid for reads at all offsets determined by dims/src_strides
  • dst must be valid for writes at all offsets determined by dims/dst_strides
  • src and dst must not overlap